==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/delete_organizations_organization_id_teams_project_team_id.py <==
from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: str,
    project_team_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "userCount",
) -> Dict[str, Any]:
    url = "{}/organizations/{organizationId}/teams/{projectTeamId}".format(
        client.hub_base_url, organizationId=organization_id, projectTeamId=project_team_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    organization_id: str,
    project_team_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "userCount",
) -> Response[Any]:
    kwargs = _get_kwargs(
        organization_id=organization_id,
        project_team_id=project_team_id,
        client=client,
        fields=fields,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    organization_id: str,
    project_team_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "userCount",
) -> Response[Any]:
    kwargs = _get_kwargs(
        organization_id=organization_id,
        project_team_id=project_team_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/delete_organizations_organization_id_teams_project_team_id.py <==
from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_id: "str",
    project_team_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "userCount",
) -> Dict[str, Any]:
    url = "{}/organizations/{organizationId}/teams/{projectTeamId}".format(
        client.hub_base_url, organizationId=organization_id, projectTeamId=project_team_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    organization_id: "str",
    project_team_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "userCount",
) -> Response[Any]:
    kwargs = _get_kwargs(
        organization_id=organization_id,
        project_team_id=project_team_id,
        client=client,
        fields=fields,
    )

    response = httpx.delete(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    organization_id: "str",
    project_team_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "userCount",
) -> Response[Any]:
    kwargs = _get_kwargs(
        organization_id=organization_id,
        project_team_id=project_team_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.delete(**kwargs)

    return _build_response(response=response)
